@@ -23,6 +23,16 @@ class MissingPasswordException(AuthenticationException):
     pass
 
 
+class MissingOTPException(AuthenticationException):
+    """An OTP was not given but 2FA is enabled"""
+    pass
+
+
+class IncorrectOTPException(AuthenticationException):
+    """An OTP was given but not accepted"""
+    pass
+
+
 class UnknownSolveException(HtbException):
     """An unknown solve type was passed"""
     pass
@@ -52,3 +62,15 @@ class IncorrectArgumentException(HtbException):
 class NoDockerException(HtbException):
     """A challenge was 'started' when no Docker is available"""
     pass
+
+
+class NoDownloadException(HtbException):
+    """A challenge was 'downloaded' when no download is available"""
+    pass
+
+
+class RateLimitException(HtbException):
+    """An internal ratelimit to prevent spam was violated"""
+    def __init__(self, message):
+        print(message)
+        super().__init__(message)
